==> vradi-entities-0.3.2-sources.jar: com/jurismarches/vradi/entities/GroupForms.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyTreeNode;
import org.nuiton.wikitty.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.WikittyTreeNodeImpl;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface GroupForms extends BusinessEntity {     String EXT_GROUPFORMS = "GroupForms";
     String FIELD_GROUPFORMS_GROUP = "group";
     String FQ_FIELD_GROUPFORMS_GROUP = EXT_GROUPFORMS + ".group";
     String FIELD_GROUPFORMS_FORM = "form";
     String FQ_FIELD_GROUPFORMS_FORM = EXT_GROUPFORMS + ".form";
    /**
     * getGroup :
     * @return String 
     */

     String getGroup();

    /**
     * setGroup :
     * @param group 
     */

     void setGroup(String group);

    /**
     * getForm :
     * @return Set<String> 
     */

     Set<String> getForm();

    /**
     * addForm :
     * @param element 
     */

     void addForm(String element);

    /**
     * removeForm :
     * @param element 
     */

     void removeForm(String element);

    /**
     * clearForm :
     */

     void clearForm();


} //GroupForms

==> vradi-entities-0.5.1-sources.jar: com/jurismarches/vradi/entities/GroupForms.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;


public interface GroupForms extends BusinessEntity {     String EXT_GROUPFORMS = "GroupForms";
     String FIELD_GROUPFORMS_GROUP = "group";
     String FQ_FIELD_GROUPFORMS_GROUP = EXT_GROUPFORMS + ".group";
     String FIELD_GROUPFORMS_FORM = "form";
     String FQ_FIELD_GROUPFORMS_FORM = EXT_GROUPFORMS + ".form";
    /**
     * getGroup :
     * @return String 
     */

     String getGroup();

    /**
     * setGroup :
     * @param group 
     */

     void setGroup(String group);

    /**
     * getForm :
     * @return Set<String> 
     */

     Set<String> getForm();

    /**
     * setForm :
     * @param form 
     */

     void setForm(Set<String> form);

    /**
     * addAllForm :
     * @param form 
     */

     void addAllForm(Set<String> form);

    /**
     * addForm :
     * @param element 
     */

     void addForm(String element);

    /**
     * removeForm :
     * @param element 
     */

     void removeForm(String element);

    /**
     * clearForm :
     */

     void clearForm();


} //GroupForms
